@@ -31,6 +31,8 @@
 # files in the program, then also delete it here.
 """Set of helpers handlers."""
 
+from __future__ import print_function
+
 import logging
 
 
@@ -51,15 +53,15 @@ class MementoHandler(logging.Handler):
     def dump_contents(self, msgs):
         """Dumps the contents of the MementoHandler."""
         if self.debug:
-            print "Expecting:"
+            print("Expecting:")
             for msg in msgs:
-                print "\t", msg
-            print "MementoHandler contents:"
+                print("\t", msg)
+            print("MementoHandler contents:")
             for rec in self.records:
-                print "\t", rec.exc_info
-                print "\t", logging.getLevelName(rec.levelno)
-                print "\t\t", rec.message
-                print "\t\t", rec.exc_text
+                print("\t", rec.exc_info)
+                print("\t", logging.getLevelName(rec.levelno))
+                print("\t\t", rec.message)
+                print("\t\t", rec.exc_text)
 
     def check(self, level, *msgs):
         """Verifies that the msgs are logged in the specified level"""
