@@ -29,12 +29,20 @@
 # files in the program, then also delete it here.
 """Utilities for finding and running a dbus session bus for testing."""
 
+from __future__ import unicode_literals
+
 import os
 import signal
 import subprocess
 
 from distutils.spawn import find_executable
-from urllib import quote
+
+# pylint: disable=F0401,E0611
+try:
+    from urllib.parse import quote
+except ImportError:
+    from urllib import quote
+# pylint: enable=F0401,E0611
 
 from ubuntuone.devtools.services import find_config_file
 DBUS_CONFIG_FILE = 'dbus-session.conf.in'
@@ -90,11 +98,12 @@ class DBusRunner(object):
         # Call wait here as under the qt4 reactor we get an error about
         # interrupted system call if we don't.
         sp.wait()
-        self.dbus_address = "".join(sp.stdout.readlines()).strip()
-        self.dbus_pid = int("".join(sp.stderr.readlines()).strip())
+        self.dbus_address = b"".join(sp.stdout.readlines()).strip()
+        self.dbus_pid = int(b"".join(sp.stderr.readlines()).strip())
 
         if self.dbus_address != "":
-            os.environ["DBUS_SESSION_BUS_ADDRESS"] = self.dbus_address
+            os.environ["DBUS_SESSION_BUS_ADDRESS"] = \
+                    self.dbus_address.decode("utf8")
         else:
             os.kill(self.dbus_pid, signal.SIGKILL)
             raise DBusLaunchError("There was a problem launching dbus-daemon.")
