@@ -27,6 +27,8 @@
 # files in the program, then also delete it here.
 """Utilities for finding and running a squid proxy for testing."""
 
+from __future__ import print_function
+
 import random
 import signal
 # pylint:disable=W0402
@@ -113,7 +115,9 @@ def kill_squid(squid_pid):
         win32api.TerminateProcess(handle, 0)
         win32api.CloseHandle(handle)
     else:
+        # pylint: disable=E1101
         kill(squid_pid, signal.SIGKILL)
+        # pylint: enable=E1101
 
 
 def _make_random_string(count):
@@ -261,7 +265,7 @@ class SquidRunner(object):
     def _is_squid_running(self):
         """Return if squid is running."""
         squid_args = ['-k', 'check', '-f', self.config_file]
-        print 'Starting squid version...'
+        print('Starting squid version...')
         message = 'Waiting for squid to start...'
         for timeout in (0.4, 0.1, 0.1, 0.2, 0.5, 1, 3, 5):
             try:
@@ -272,7 +276,7 @@ class SquidRunner(object):
                 return True
             except subprocess.CalledProcessError:
                 message += '.'
-                print message
+                print(message)
                 time.sleep(timeout)
         return False
 
